<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">წაშლა</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">მთელს ეკრანზე</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">სლაიდშოუ</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">ექსპორტი</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">კოპირება</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">ფავორიტი</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">საათის ისრის მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">საათის ისრის საწინააღმდეგო მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">ფონად დაყენება</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">ფაილების მენეჯერში ნახვა</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">ინფორმაცია</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">აღდგენა</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>უსახელო</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>შექმნა</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>ახალი ალბომი</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>დარწმუნებული ხართ, რომ გსურთ ამ ალბომის წაშლა?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>სანაგვე</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ფავორიტები</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>იმპორტი</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>სანაგვე</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ფავორიტი</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>ან გადმოიტანეთ ფოტო აქ</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>ყველა</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>იმპორტირება:  </translation>
    </message>
    <message>
        <source>Import</source>
        <translation>იმპორტი</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>სისტემური დისკი</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>გალერეა</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>დისკი დაკავებულია, ამჟამად ამოღება შეუძლებელია</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ოკ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ახალი ალბომი</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>იგნორირება</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>ალბომი</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>ჩანაცვლება</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ექსპორტი</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>სურათები</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>დოკუმენტები</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>ჩამოტვირთვები</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>ეკრანი</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>ვიდეოები</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>მუსიკები</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>სახელი:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>საქაღალდე:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>ფორმატი:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>ხარისხი:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>შენახვა</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>სხვა საქაღალდის არჩევა</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ოკ</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>ფაილის სახელი არ უნდა იყოს ცარიელი</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>უკვე არსებობს, ჩავანაცვლოთ?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 დრაივი</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>%1 ბლანკი დისკი</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 დაშიფრული</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 ვოლუმი</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>შენახვა</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>ფოტოების ექსპორტი</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>წაშლა...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>აღდგენა...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>საბაზო ინფორმაცია</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>დეტალები</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>იმპორტი</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>სლაიდშოუ</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>გადარქმევა</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ექსპორტი</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>მოწყობილობა</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>გალერეა</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>ალბომები</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ახალი ალბომი</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>სურათები</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>მთელს ეკრანზე</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>დახმარება</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ფაილების მენეჯერში ნახვა</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>სლაიდშოუ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>კოპირება</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>ფონად დაყენება</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>საათის ისრის მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>საათის ისრის საწინააღმდეგო მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>წინა</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>შემდეგი</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ფავორიტი</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ფავორიტებიდან წაშლა</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>ალბომის გადარქმევა</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>ალბომი %1 წაიშალა</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>წარმატებით დაემატა &quot;%1&quot;-ში</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>იპორტი წარმატებით დასრულდა</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>იმპორტი შეწყდა</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>ექსპორტი შეწყდა</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>ექსპორტი წარმატებით დასრულდა</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>სურათები</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>თაიმლაინი</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>ალბომები</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>მთლიანი ეკრანიდან/სლაიდშოუდან გამოსვლა</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>შორთქატების ჩვენება</translation>
    </message>
    <message>
        <source>View</source>
        <translation>ნახვა</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>ყველას მონიშვნა</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>გადიდება</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>დაპატარავება</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ახალი ალბომი</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>ზემოთ ასვლა</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>ქვემოთ ჩამოსვლა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>იმპორტი...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">წაშლა</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>ფლეში</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ტიპი</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>ფაილის ზომა</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>გაფართოება</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>გადაღების დრო</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>ცვლილების დრო</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>ექსპოზიციის რეჟიმი</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>ექსპოზიციის პროგრამა</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>ექსპოზიციის დრო</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>დიაფრაგმა</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>ფოკალური სიგრძე</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>მაქსიმალური დიაფრაგმა</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>დათვლის რეჟიმი</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>თეთრი ფერის ბალანსი</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>ფლეშ კომპენსაცია</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>კამერის მოდელი</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>ლინზის მოდელი</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>ფერთა სივრცე</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>თეგი</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>სისტემური დისკი</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>არჩევა</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>იმპორტირებულია: </translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation>%1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>იმპორტირებულია: </translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>აღდგენა</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>სურათები</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>ვიდეოები</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ფავორიტი</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>საათის ისრის საწინააღმდეგო მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>საათის ისრის მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>იმპორტი...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>არ მოიძებნა არაფერი</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>სლაიდშოუ</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>ძებნის რეზულტატი</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>ნახვა</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>მთელს ეკრანზე</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ექსპორტი</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ფავორიტი</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ფავორიტებიდან წაშლა</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>საათის ისრის მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>საათის ისრის საწინააღმდეგო მიმართულებით დაბრუნება</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ფაილების მენეჯერში ნახვა</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>ფონად დაყენება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>სლაიდშოუ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>კოპირება</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>ინფორმაცია</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>ალბომში დამატება</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ალბომის წაშლა</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>აღდგენა</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ახალი ალბომი</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>დაბეჭდვა</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"> დღე</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">საბაზო ინფორმაცია</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">ცვლილების დრო</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">ტიპი</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">ფაილის ზომა</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">გადაღების დრო</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
